changeset 111331:f3a306e9418e

landmark: you lose. * lisp/play/landmark.el (lm-losing-threshold): Correct spelling. (lm-human-plays): Use new name.
author Glenn Morris <rgm@gnu.org>
date Tue, 02 Nov 2010 20:35:38 -0700
parents 651ebb81e47d
children 13a509edfa26
files lisp/ChangeLog lisp/play/landmark.el
diffstat 2 files changed, 7 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Tue Nov 02 20:33:24 2010 -0700
+++ b/lisp/ChangeLog	Tue Nov 02 20:35:38 2010 -0700
@@ -1,5 +1,8 @@
 2010-11-03  Glenn Morris  <rgm@gnu.org>
 
+	* play/landmark.el (lm-losing-threshold): Correct spelling.
+	(lm-human-plays): Use new name.
+
 	* play/gomoku.el (gomoku-loosing-threshold): Correct spelling.
 	(gomoku-human-plays): Use new name.
 
--- a/lisp/play/landmark.el	Tue Nov 02 20:33:24 2010 -0700
+++ b/lisp/play/landmark.el	Tue Nov 02 20:35:38 2010 -0700
@@ -282,7 +282,7 @@
 ;; its contents as a set, i.e. not considering the order of its elements. The
 ;; highest score is given to the "OOOO" qtuples because playing in such a
 ;; qtuple is winning the game. Just after this comes the "XXXX" qtuple because
 ;; not playing in it is just loosing the game, and so on. Note that a
 ;; "polluted" qtuple, i.e. one containing at least one X and at least one O,
 ;; has score zero because there is no more any point in playing in it, from
 ;; both an attacking and a defending point of view.
@@ -352,13 +352,13 @@
 ;; qtuple, thus to be a winning move. Similarly, the only way for a square to
 ;; have a score between XXXXscore and OOOOscore is to belong to a "XXXX"
 ;; qtuple. We may use these considerations to detect when a given move is
 ;; winning or loosing.
 
 (defconst lm-winning-threshold
   (aref lm-score-trans-table (+ 6 6 6 6)) ;; OOOOscore
   "Threshold score beyond which an Emacs move is winning.")
 
-(defconst lm-loosing-threshold
+(defconst lm-losing-threshold
   (aref lm-score-trans-table (+ 1 1 1 1)) ;; XXXXscore
   "Threshold score beyond which a human move is winning.")
 
@@ -771,7 +771,7 @@
 	    (t
 	     (setq score (aref lm-score-table square))
 	     (lm-play-move square 1)
-	     (cond ((and (>= score lm-loosing-threshold)
+	     (cond ((and (>= score lm-losing-threshold)
 			 ;; Just testing SCORE > THRESHOLD is not enough for
 			 ;; detecting wins, it just gives an indication that
 			 ;; we confirm with LM-FIND-FILLED-QTUPLE.
@@ -282,7 +282,7 @@
 ;; highest score is given to the "OOOO" qtuples because playing in such a
 ;; qtuple is winning the game. Just after this comes the "XXXX" qtuple because
-;; not playing in it is just loosing the game, and so on. Note that a
+;; not playing in it is just losing the game, and so on. Note that a
 ;; "polluted" qtuple, i.e. one containing at least one X and at least one O,
 ;; has score zero because there is no more any point in playing in it, from
@@ -352,13 +352,13 @@
 ;; have a score between XXXXscore and OOOOscore is to belong to a "XXXX"
 ;; qtuple. We may use these considerations to detect when a given move is
-;; winning or loosing.
+;; winning or losing.
 
 (defconst lm-winning-threshold